@@ -17,8 +17,10 @@ if ($gemini = $obj->findDevice(product => "Gemini")) {
 }
 else {
     print "No Gemini found, opening network client\n";
+    $gemini = 'network,Robotics::Tecan::Genesis,genesis0';
     $hw = Robotics::Tecan->new(
-        connection => 'network,Robotics::Tecan::Genesis,genesis0',
+        connection => $gemini,
+        simulate => 'yes',
         token => 'M1',
         serveraddr => 'heavybio.dyndns.org:8088',
         password => $ENV{'TECANPASSWORD'});
@@ -30,11 +32,11 @@ if (!$hw) {
 print "Managing hardware\n";
 my $manager = Robotics->new(
         device => $hw,
+#        connection => $gemini,
         alias => "worker1");
 
 print "Attaching to hardware\n";
-print $hw->attach();
-print $hw->status();
+#print $hw->attach();
 print $hw->status();
 print $hw->initialize();
 print $hw->status();
@@ -45,16 +47,52 @@ warn "
 # 
 ";
 
-print "ROBOT ARMS WILL MOVE!!  Is this okay?  (must type 'yes') [no]:";
-$_ = <STDIN>;
-if (!($_ =~ m/yes/i)) { 
-    exit -4;
-}
+#print "ROBOT ARMS WILL MOVE!!  Is this okay?  (must type 'yes') [no]:";
+#$_ = <STDIN>;
+#if (!($_ =~ m/yes/i)) { 
+#    exit -4;
+#}
 
+$hw->configure("client-traymove1test.yaml");
+
+print "\n\n\n\n";
+my $result;
 $hw->command("ROMA_PARK", grippos => "0"); print "\t".$hw->Read()."\n\n";
 $hw->command("ROMA_PARK", grippos => "1"); print "\t".$hw->Read()."\n\n";
 $hw->command("ROMA_PARK", grippos => "2"); print "\t".$hw->Read()."\n\n";
 $hw->park();
+$hw->park("liha0");
+$hw->move_object(
+#        on => "JCplateholder", 
+        at => "JCgreinerVbottom96", 
+        position => "1,2,1",
+        to => "JCmagholder");
+$hw->park();
+
+if (0) { 
+$result = $hw->aspirate(
+        on => "JCmagholder", 
+        at => "JCgreinerVbottom96", 
+        well => "A1", volume => "100u"); 
+print "Aspirate: $result\n";
+
+$result = $hw->dispense(
+        on => "JCmagholder", 
+        at => "JCgreinerVbottom96", 
+        well => "A1", volume => "100u"); 
+print "Dispense: $result\n";
+$hw->park("liha0");
+}
+
+$hw->move_object(
+        on => "JCmagholder", 
+        at => "JCgreinerVbottom96", 
+        position => "1,1,1", 
+        to => "JCplateholder");
+
+$hw->park("liha0");
 $hw->detach();
 
 1;
+__END__
+
